##  Downloading a Report
Follow these steps:
  1. Navigate to the SAP LeanIX Store from your workspace. To do that, on the navigation bar, choose More > Store.
  2. Browse the SAP LeanIX Store to view available reports and select the report that you want to download.
  3. On the report page, select the appropriate option to download the report to a single or multiple workspaces:
     * Add to Workspace: Download the report to the workspace that you're currently signed in to.
     * Add to Workspaces: Select workspaces for which you have admin permissions to download the report to.
  4. Read the Terms & Conditions of the report provider, then click I Agree.


The report is added to selected workspaces, but it doesn't automatically appear on the Reports page. To learn how to activate a report and make it available to non-admin users, read the following section.
